=== added file 'CMakeLists.txt'
--- CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ CMakeLists.txt	2014-09-17 20:40:39 +0000
@@ -0,0 +1,151 @@
+cmake_minimum_required(VERSION 2.8.9)
+
+project(qtmir)
+
+set(QTMIR_VERSION_MAJOR 0)
+set(QTMIR_VERSION_MINOR 1)
+set(QTMIR_VERSION_PATCH 0)
+
+if(${PROJECT_BINARY_DIR} STREQUAL ${PROJECT_SOURCE_DIR})
+   message(FATAL_ERROR "In-tree build attempt detected, aborting. Set your build dir outside your source dir, delete CMakeCache.txt and CMakeFiles/ from source root and try again.")
+endif()
+
+# Find includes in corresponding build directories
+set(CMAKE_INCLUDE_CURRENT_DIR ON)
+
+# add custom cmake modules
+set(CMAKE_MODULE_PATH ${CMAKE_MODULE_PATH} ${CMAKE_CURRENT_SOURCE_DIR}/cmake/modules)
+
+# Instruct CMake to run moc automatically when needed.
+set(CMAKE_AUTOMOC ON)
+
+set(CMAKE_C_FLAGS "${CMAKE_C_FLAGS} -std=c99 -Wall -pedantic -Wextra")
+set(CMAKE_CXX_FLAGS "${CMAKE_CXX_FLAGS} -std=c++11 -Wall -fno-strict-aliasing -pedantic -Wextra")
+set(CMAKE_SHARED_LINKER_FLAGS "${CMAKE_SHARED_LINKER_FLAGS} -Wl,--no-undefined")
+
+
+include(EnableCoverageReport)
+#####################################################################
+# Enable code coverage calculation with gcov/gcovr/lcov
+# Usage:
+#  * Switch build type to coverage (use ccmake or cmake-gui)
+#  * Invoke make, make test, make coverage (or ninja if you use that backend)
+#  * Find html report in subdir coveragereport
+#  * Find xml report feasible for jenkins in coverage.xml
+#####################################################################
+if(cmake_build_type_lower MATCHES coverage)
+    set(CMAKE_C_FLAGS "${CMAKE_C_FLAGS} --coverage" )
+    set(CMAKE_CXX_FLAGS "${CMAKE_CXX_FLAGS} --coverage" )
+    set(CMAKE_MODULE_LINKER_FLAGS "${CMAKE_MODULE_LINKER_FLAGS} --coverage" )
+    set(CMAKE_SHARED_LINKER_FLAGS "${CMAKE_SHARED_LINKER_FLAGS} --coverage" )
+    ENABLE_COVERAGE_REPORT(TARGETS ${SHELL_APP} FILTER /usr/include ${CMAKE_SOURCE_DIR}/tests/* ${CMAKE_BINARY_DIR}/*)
+endif()
+
+# Make sure we have all the needed symbols
+set(CMAKE_SHARED_LINKER_FLAGS "${CMAKE_SHARED_LINKER_FLAGS} -Wl,-z,defs")
+set(CMAKE_MODULE_LINKER_FLAGS "${CMAKE_MODULE_LINKER_FLAGS} -Wl,-z,defs")
+
+# Static C++ checks
+add_custom_target(cppcheck COMMAND cppcheck --enable=all -q --error-exitcode=2
+                                       ${CMAKE_SOURCE_DIR}/src ${CMAKE_SOURCE_DIR}/tests)
+
+include(FindPkgConfig)
+find_package(Qt5Core 5.2 REQUIRED)
+find_package(Qt5DBus 5.2 REQUIRED)
+find_package(Qt5Gui 5.2 REQUIRED)
+find_package(Qt5Qml 5.2 REQUIRED)
+find_package(Qt5Quick 5.2 REQUIRED)
+
+find_package(Threads REQUIRED)
+find_package(Boost 1.50 COMPONENTS system REQUIRED)
+
+find_package(Protobuf REQUIRED)
+if(PROTOBUF_PROTOC_EXECUTABLE STREQUAL "PROTOBUF_PROTOC_EXECUTABLE-NOTFOUND")
+    message(SEND_ERROR "protoc executable not found! Missing protobuf-compiler package?")
+endif()
+
+pkg_check_modules(MIRSERVER mirserver REQUIRED)
+pkg_check_modules(MIRCOMMON mircommon REQUIRED)
+
+# detect if Qt compiled with GL or GLES
+include(CheckCXXSourceCompiles)
+check_cxx_source_compiles("
+#include <QtCore/QtGlobal>
+#if !defined(QT_OPENGL_ES)
+#error \"No OpenGLES\"
+#endif
+int main() {}
+" USE_OPENGLES)
+
+if (USE_OPENGLES)
+    message(STATUS "Qt5 determined to be compiled with GLES support")
+    find_package(GLESv2 REQUIRED)
+    add_definitions(-DQT_USING_GLES)
+    include_directories (${GLESv2_INCLUDE_DIRS})
+    set (GL_LIBRARIES "${GLESv2_LIBRARIES}")
+
+else()
+    message(STATUS "Qt5 determined to be compiled with OpenGL support")
+    find_package(OpenGL REQUIRED)
+    add_definitions(-DQT_USING_OPENGL)
+    include_directories (${OpenGL_INCLUDE_DIRS})
+    set (GL_LIBRARIES "${OPENGL_gl_LIBRARY}")
+endif()
+
+# Standard install paths
+include(GNUInstallDirs)
+
+
+# Determine QPA plugin install path
+# FIXME(greyback) there must be a better way than calling a private macro to set a property.
+# I'm manually calling a macro from Qt5GuiConfig.cmake, but I don't understand why it isn't being called.
+_populate_Gui_plugin_properties("Gui" "PLATFORMS" "platforms")
+get_target_property(Qt5Gui_QPA_Plugin_Path Qt5::Gui IMPORTED_LOCATION_PLATFORMS)
+
+# Determine install path for QML module
+execute_process(COMMAND ${PKG_CONFIG_EXECUTABLE} --variable=plugindir_suffix unity-shell-api OUTPUT_VARIABLE QTMIR_INSTALL_QML OUTPUT_STRIP_TRAILING_WHITESPACE)
+if(SHELL_INSTALL_QML STREQUAL "")
+    message(FATAL_ERROR "Could not determine plugin installation dir.")
+endif()
+
+execute_process(COMMAND ${PKG_CONFIG_EXECUTABLE} --variable=plugindir unity-shell-api OUTPUT_VARIABLE QTMIR_PLUGINDIR OUTPUT_STRIP_TRAILING_WHITESPACE)
+if(SHELL_PLUGINDIR STREQUAL "")
+    message(FATAL_ERROR "Could not determine plugin import dir.")
+endif()
+
+
+
+# Customisations for the build type
+if(NOT CMAKE_BUILD_TYPE)
+    message(STATUS "Setting build type to 'RelWithDebInfo' as none was specified.")
+    set(CMAKE_BUILD_TYPE RelWithDebInfo)
+endif()
+
+string(TOLOWER "${CMAKE_BUILD_TYPE}" cmake_build_type_lower)
+
+if(cmake_build_type_lower MATCHES relwithdebinfo) # workaround for http://public.kitware.com/Bug/view.php?id=14696
+    add_definitions(-DQT_NO_DEBUG)
+endif()
+if ("${CMAKE_BUILD_TYPE}" STREQUAL "release" OR "${CMAKE_BUILD_TYPE}" STREQUAL "relwithdebinfo")
+    option(Werror "Treat warnings as errors" ON)
+else()
+    option(Werror "Treat warnings as errors" OFF)
+endif()
+
+if (Werror)
+    set(CMAKE_CXX_FLAGS "${CMAKE_CXX_FLAGS} -Werror")
+endif()
+
+
+# Mir uses boost, which does not like Qt defining macros named "signals" and "slots"
+#add_definitions(-DQT_NO_KEYWORDS)
+
+# Tests
+include(CTest)
+enable_testing()
+
+
+# add subdirectories to build
+add_subdirectory(src)
+#add_subdirectory(demos)
+

=== added directory 'cmake'
=== added directory 'cmake/modules'
=== added file 'cmake/modules/EnableCoverageReport.cmake'
--- cmake/modules/EnableCoverageReport.cmake	1970-01-01 00:00:00 +0000
+++ cmake/modules/EnableCoverageReport.cmake	2014-09-17 20:40:39 +0000
@@ -0,0 +1,166 @@
+# - Creates a special coverage build type and target on GCC.
+#
+# Defines a function ENABLE_COVERAGE_REPORT which generates the coverage target
+# for selected targets. Optional arguments to this function are used to filter
+# unwanted results using globbing expressions. Moreover targets with tests for
+# the source code can be specified to trigger regenerating the report if the
+# test has changed
+#
+# ENABLE_COVERAGE_REPORT(TARGETS target... [FILTER filter...] [TESTS test targets...])
+#
+# To generate a coverage report first build the project with
+# CMAKE_BUILD_TYPE=coverage, then call make test and afterwards make coverage.
+#
+# The coverage report is based on gcov. Depending on the availability of lcov
+# a HTML report will be generated and/or an XML report of gcovr is found.
+# The generated coverage target executes all found solutions. Special targets
+# exist to create e.g. only the xml report: coverage-xml. 
+#
+# Copyright (C) 2010 by Johannes Wienke <jwienke at techfak dot uni-bielefeld dot de>
+#
+# This program is free software; you can redistribute it
+# and/or modify it under the terms of the GNU General
+# Public License as published by the Free Software Foundation;
+# either version 2, or (at your option)
+# any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+
+INCLUDE(ParseArguments)
+
+FIND_PACKAGE(Lcov)
+FIND_PACKAGE(gcovr)
+
+FUNCTION(ENABLE_COVERAGE_REPORT)
+    
+    # argument parsing
+    PARSE_ARGUMENTS(ARG "FILTER;TARGETS;TESTS" "" ${ARGN})
+    
+    SET(COVERAGE_RAW_FILE "${CMAKE_BINARY_DIR}/coverage.raw.info")
+    SET(COVERAGE_FILTERED_FILE "${CMAKE_BINARY_DIR}/coverage.info")
+    SET(COVERAGE_REPORT_DIR "${CMAKE_BINARY_DIR}/coveragereport")
+    SET(COVERAGE_XML_FILE "${CMAKE_BINARY_DIR}/coverage.xml")
+    SET(COVERAGE_XML_COMMAND_FILE "${CMAKE_BINARY_DIR}/coverage-xml.cmake")
+    
+    # decide if there is any tool to create coverage data
+    SET(TOOL_FOUND FALSE)
+    IF(LCOV_FOUND OR GCOVR_FOUND)
+        SET(TOOL_FOUND TRUE)
+    ENDIF()
+    IF(NOT TOOL_FOUND)
+        MESSAGE(STATUS "Cannot enable coverage targets because neither lcov nor gcovr are found.")
+    ENDIF()
+    
+    STRING(TOLOWER "${CMAKE_BUILD_TYPE}" COVERAGE_BUILD_TYPE)
+    IF(CMAKE_COMPILER_IS_GNUCXX AND TOOL_FOUND AND "${COVERAGE_BUILD_TYPE}" MATCHES "coverage")
+    
+        MESSAGE(STATUS "Coverage support enabled for targets: ${ARG_TARGETS}")
+    
+        # create coverage build type
+        SET(CMAKE_CXX_FLAGS_COVERAGE ${CMAKE_CXX_FLAGS_DEBUG} PARENT_SCOPE)
+        SET(CMAKE_C_FLAGS_COVERAGE ${CMAKE_C_FLAGS_DEBUG} PARENT_SCOPE)
+        SET(CMAKE_CONFIGURATION_TYPES ${CMAKE_CONFIGURATION_TYPES} coverage PARENT_SCOPE)
+    
+        # instrument targets
+        SET_TARGET_PROPERTIES(${ARG_TARGETS} PROPERTIES COMPILE_FLAGS --coverage
+                                                        LINK_FLAGS --coverage)
+    
+        # html report
+        IF (LCOV_FOUND)
+        
+            MESSAGE(STATUS "Enabling HTML coverage report")
+    
+            # set up coverage target
+            
+            ADD_CUSTOM_COMMAND(OUTPUT ${COVERAGE_RAW_FILE}
+                               COMMAND ${LCOV_EXECUTABLE} -c -d ${CMAKE_BINARY_DIR} -o ${COVERAGE_RAW_FILE}
+                               WORKING_DIRECTORY ${CMAKE_BINARY_DIR}
+                               COMMENT "Collecting coverage data"
+                               DEPENDS ${ARG_TARGETS} ${ARG_TESTS}
+                               VERBATIM)
+            
+            # filter unwanted stuff
+            LIST(LENGTH ARG_FILTER FILTER_LENGTH)
+            IF(${FILTER_LENGTH} GREATER 0)
+                SET(FILTER COMMAND ${LCOV_EXECUTABLE})
+                FOREACH(F ${ARG_FILTER})
+                    SET(FILTER ${FILTER} -r ${COVERAGE_FILTERED_FILE} ${F})
+                ENDFOREACH()
+                SET(FILTER ${FILTER} -o ${COVERAGE_FILTERED_FILE})
+            ELSE()
+                SET(FILTER "")
+            ENDIF()
+            
+            ADD_CUSTOM_COMMAND(OUTPUT ${COVERAGE_FILTERED_FILE}
+                               COMMAND ${LCOV_EXECUTABLE} -e ${COVERAGE_RAW_FILE} "${CMAKE_SOURCE_DIR}*"  -o ${COVERAGE_FILTERED_FILE}
+                               ${FILTER}
+                               DEPENDS ${COVERAGE_RAW_FILE}
+                               COMMENT "Filtering recorded coverage data for project-relevant entries"
+                               VERBATIM)
+            ADD_CUSTOM_COMMAND(OUTPUT ${COVERAGE_REPORT_DIR}
+                               COMMAND ${CMAKE_COMMAND} -E make_directory ${COVERAGE_REPORT_DIR}
+                               COMMAND ${GENHTML_EXECUTABLE} --legend --show-details -t "${PROJECT_NAME} test coverage" -o ${COVERAGE_REPORT_DIR} ${COVERAGE_FILTERED_FILE}
+                               DEPENDS ${COVERAGE_FILTERED_FILE}
+                               COMMENT "Generating HTML coverage report in ${COVERAGE_REPORT_DIR}"
+                               VERBATIM)
+                               
+            ADD_CUSTOM_TARGET(coverage-html
+                              DEPENDS ${COVERAGE_REPORT_DIR})
+                              
+        ENDIF()
+        
+        # xml coverage report
+        IF(GCOVR_FOUND)
+        
+            MESSAGE(STATUS "Enabling XML coverage report")
+
+            # filter unwanted stuff
+            SET(GCOV_FILTER "")
+            LIST(LENGTH ARG_FILTER FILTER_LENGTH)
+            IF(${FILTER_LENGTH} GREATER 0)
+                FOREACH(F ${ARG_FILTER})
+                    SET(GCOV_FILTER "${GCOV_FILTER} -e \"${F}\"")
+                ENDFOREACH()
+            ENDIF()
+
+            # gcovr cannot write directly to a file so the execution needs to
+            # be wrapped in a cmake file that generates the file output
+            FILE(WRITE ${COVERAGE_XML_COMMAND_FILE}
+                 "SET(ENV{LANG} en)\n")
+            FILE(APPEND ${COVERAGE_XML_COMMAND_FILE}
+                 "EXECUTE_PROCESS(COMMAND \"${GCOVR_EXECUTABLE}\" -x -r \"${CMAKE_SOURCE_DIR}\" ${GCOV_FILTER} OUTPUT_FILE \"${COVERAGE_XML_FILE}\" WORKING_DIRECTORY \"${CMAKE_BINARY_DIR}\")\n")
+        
+            ADD_CUSTOM_COMMAND(OUTPUT ${COVERAGE_XML_FILE}
+                               COMMAND ${CMAKE_COMMAND} ARGS -P ${COVERAGE_XML_COMMAND_FILE}
+                               COMMENT "Generating coverage XML report"
+                               VERBATIM)
+                               
+            ADD_CUSTOM_TARGET(coverage-xml
+                              DEPENDS ${COVERAGE_XML_FILE})
+        
+        ENDIF()
+        
+        # provide a global coverage target executing both steps if available
+        SET(GLOBAL_DEPENDS "")
+        IF(LCOV_FOUND)
+            LIST(APPEND GLOBAL_DEPENDS ${COVERAGE_REPORT_DIR})
+        ENDIF()
+        IF(GCOVR_FOUND)
+            LIST(APPEND GLOBAL_DEPENDS ${COVERAGE_XML_FILE})
+        ENDIF()
+        IF(LCOV_FOUND OR GCOVR_FOUND)
+            ADD_CUSTOM_TARGET(coverage
+                              DEPENDS ${GLOBAL_DEPENDS})
+        ENDIF()
+                          
+    ENDIF()
+
+    # This gets rid of any stale .gcda files. Run this if a running a binary causes lots of messages about
+    # about a "merge mismatch for summaries".
+    ADD_CUSTOM_TARGET(clean-coverage COMMAND find ${CMAKE_BINARY_DIR} -name '*.gcda' | xargs rm -f)
+
+ENDFUNCTION()   

=== added file 'cmake/modules/FindLcov.cmake'
--- cmake/modules/FindLcov.cmake	1970-01-01 00:00:00 +0000
+++ cmake/modules/FindLcov.cmake	2014-09-17 20:40:39 +0000
@@ -0,0 +1,29 @@
+# - Find lcov 
+# Will define:
+#
+# LCOV_EXECUTABLE - the lcov binary
+# GENHTML_EXECUTABLE - the genhtml executable
+#
+# Copyright (C) 2010 by Johannes Wienke <jwienke at techfak dot uni-bielefeld dot de>
+#
+# This program is free software; you can redistribute it
+# and/or modify it under the terms of the GNU General
+# Public License as published by the Free Software Foundation;
+# either version 2, or (at your option)
+# any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+
+INCLUDE(FindPackageHandleStandardArgs)
+
+FIND_PROGRAM(LCOV_EXECUTABLE lcov)
+FIND_PROGRAM(GENHTML_EXECUTABLE genhtml)
+
+FIND_PACKAGE_HANDLE_STANDARD_ARGS(Lcov DEFAULT_MSG LCOV_EXECUTABLE GENHTML_EXECUTABLE)
+
+# only visible in advanced view
+MARK_AS_ADVANCED(LCOV_EXECUTABLE GENHTML_EXECUTABLE)

=== added file 'cmake/modules/Findgcovr.cmake'
--- cmake/modules/Findgcovr.cmake	1970-01-01 00:00:00 +0000
+++ cmake/modules/Findgcovr.cmake	2014-09-17 20:40:39 +0000
@@ -0,0 +1,31 @@
+# - Find gcovr scrip 
+# Will define:
+#
+# GCOVR_EXECUTABLE - the gcovr script
+#
+# Uses:
+#
+# GCOVR_ROOT - root to search for the script
+#
+# Copyright (C) 2011 by Johannes Wienke <jwienke at techfak dot uni-bielefeld dot de>
+#
+# This program is free software; you can redistribute it
+# and/or modify it under the terms of the GNU General
+# Public License as published by the Free Software Foundation;
+# either version 2, or (at your option)
+# any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+
+INCLUDE(FindPackageHandleStandardArgs)
+
+FIND_PROGRAM(GCOVR_EXECUTABLE gcovr HINTS ${GCOVR_ROOT} "${GCOVR_ROOT}/bin")
+
+FIND_PACKAGE_HANDLE_STANDARD_ARGS(gcovr DEFAULT_MSG GCOVR_EXECUTABLE)
+
+# only visible in advanced view
+MARK_AS_ADVANCED(GCOVR_EXECUTABLE)

=== added file 'cmake/modules/ParseArguments.cmake'
--- cmake/modules/ParseArguments.cmake	1970-01-01 00:00:00 +0000
+++ cmake/modules/ParseArguments.cmake	2014-09-17 20:40:39 +0000
@@ -0,0 +1,52 @@
+# Parse arguments passed to a function into several lists separated by
+# upper-case identifiers and options that do not have an associated list e.g.:
+#
+# SET(arguments
+#   hello OPTION3 world
+#   LIST3 foo bar
+#   OPTION2
+#   LIST1 fuz baz
+#   )
+# PARSE_ARGUMENTS(ARG "LIST1;LIST2;LIST3" "OPTION1;OPTION2;OPTION3" ${arguments})
+#
+# results in 7 distinct variables:
+#  * ARG_DEFAULT_ARGS: hello;world
+#  * ARG_LIST1: fuz;baz
+#  * ARG_LIST2:
+#  * ARG_LIST3: foo;bar
+#  * ARG_OPTION1: FALSE
+#  * ARG_OPTION2: TRUE
+#  * ARG_OPTION3: TRUE
+#
+# taken from http://www.cmake.org/Wiki/CMakeMacroParseArguments 
+
+MACRO(PARSE_ARGUMENTS prefix arg_names option_names)
+    SET(DEFAULT_ARGS)
+    FOREACH(arg_name ${arg_names})    
+        SET(${prefix}_${arg_name})
+    ENDFOREACH(arg_name)
+    FOREACH(option ${option_names})
+        SET(${prefix}_${option} FALSE)
+    ENDFOREACH(option)
+    
+    SET(current_arg_name DEFAULT_ARGS)
+    SET(current_arg_list)
+    FOREACH(arg ${ARGN})            
+        SET(larg_names ${arg_names})    
+        LIST(FIND larg_names "${arg}" is_arg_name)                   
+        IF (is_arg_name GREATER -1)
+            SET(${prefix}_${current_arg_name} ${current_arg_list})
+            SET(current_arg_name ${arg})
+            SET(current_arg_list)
+        ELSE (is_arg_name GREATER -1)
+            SET(loption_names ${option_names})    
+            LIST(FIND loption_names "${arg}" is_option)            
+            IF (is_option GREATER -1)
+                SET(${prefix}_${arg} TRUE)
+            ELSE (is_option GREATER -1)
+                SET(current_arg_list ${current_arg_list} ${arg})
+            ENDIF (is_option GREATER -1)
+        ENDIF (is_arg_name GREATER -1)
+    ENDFOREACH(arg)
+    SET(${prefix}_${current_arg_name} ${current_arg_list})
+ENDMACRO(PARSE_ARGUMENTS)

=== added file 'cmake/modules/Plugins.cmake'
--- cmake/modules/Plugins.cmake	1970-01-01 00:00:00 +0000
+++ cmake/modules/Plugins.cmake	2014-09-17 20:40:39 +0000
@@ -0,0 +1,68 @@
+find_program(qmlplugindump_exe qmlplugindump)
+
+if(NOT qmlplugindump_exe)
+  msg(FATAL_ERROR "Could not locate qmlplugindump.")
+endif()
+
+# Creates target for copying and installing qmlfiles
+#
+# export_qmlfiles(plugin sub_path)
+#
+#
+# Target to be created:
+#   - plugin-qmlfiles - Copies the qml files (*.qml, *.js, qmldir) into the shadow build folder.
+
+macro(export_qmlfiles PLUGIN PLUGIN_SUBPATH)
+
+    file(GLOB QMLFILES
+        *.qml
+        *.js
+        qmldir
+    )
+
+    # copy the qmldir file
+    add_custom_target(${PLUGIN}-qmlfiles ALL
+                        COMMAND cp ${QMLFILES} ${CMAKE_BINARY_DIR}/plugins/${PLUGIN_SUBPATH}
+                        DEPENDS ${QMLFILES}
+                        SOURCES ${QMLFILES}
+    )
+
+    # install the qmlfiles file.
+    install(FILES ${QMLFILES}
+        DESTINATION ${SHELL_INSTALL_QML}/${PLUGIN_SUBPATH}
+    )
+endmacro(export_qmlfiles)
+
+
+# Creates target for generating the qmltypes file for a plugin and installs plugin files
+#
+# export_qmlplugin(plugin version sub_path [TARGETS target1 [target2 ...]])
+#
+# TARGETS additional install targets (eg the plugin shared object)
+#
+# Target to be created:
+#   - plugin-qmltypes - Generates the qmltypes file in the shadow build folder.
+
+macro(export_qmlplugin PLUGIN VERSION PLUGIN_SUBPATH)
+    set(multi_value_keywords TARGETS)
+    cmake_parse_arguments(qmlplugin "" "" "${multi_value_keywords}" ${ARGN})
+
+    # Only try to generate .qmltypes if not cross compiling
+    if(NOT CMAKE_CROSSCOMPILING)
+        # create the plugin.qmltypes file
+        add_custom_target(${PLUGIN}-qmltypes ALL
+            COMMAND ${qmlplugindump_exe} -notrelocatable ${PLUGIN} ${VERSION} ${CMAKE_BINARY_DIR}/plugins > ${CMAKE_BINARY_DIR}/plugins/${PLUGIN_SUBPATH}/plugin.qmltypes
+        )
+        add_dependencies(${PLUGIN}-qmltypes ${PLUGIN}-qmlfiles ${qmlplugin_TARGETS})
+
+        # install the qmltypes file.
+        install(FILES ${CMAKE_BINARY_DIR}/plugins/${PLUGIN_SUBPATH}/plugin.qmltypes
+            DESTINATION ${SHELL_INSTALL_QML}/${PLUGIN_SUBPATH}
+        )
+    endif()
+
+    # install the additional targets
+    install(TARGETS ${qmlplugin_TARGETS}
+        DESTINATION ${SHELL_INSTALL_QML}/${PLUGIN_SUBPATH}
+    )
+endmacro(export_qmlplugin)

=== added file 'cmake/modules/QmlTest.cmake'
--- cmake/modules/QmlTest.cmake	1970-01-01 00:00:00 +0000
+++ cmake/modules/QmlTest.cmake	2014-09-17 20:40:39 +0000
@@ -0,0 +1,192 @@
+# add_qml_test(path component_name [NO_ADD_TEST] [NO_TARGETS]
+#              [TARGETS target1 [target2 [...]]]
+#              [IMPORT_PATHS import_path1 [import_path2 [...]]
+#              [PROPERTIES prop1 value1 [prop2 value2 [...]]])
+#
+# NO_ADD_TEST will prevent adding the test to the "test" target
+# NO_TARGETS will prevent adding the test to any targets
+# TARGETS lists the targets the test should be added to
+# IMPORT_PATHS will pass those paths to qmltestrunner as "-import" arguments
+# PROPERTIES will be set on the target and test target. See CMake's set_target_properties()
+#
+# Two targets will be created:
+#   - testComponentName - Runs the test with qmltestrunner
+#   - tryComponentName - Runs the test with uqmlscene, for manual interaction
+#
+# To change/set a default value for the whole test suite, prior to calling add_qml_test, set:
+# qmltest_DEFAULT_NO_ADD_TEST (default: FALSE)
+# qmltest_DEFAULT_TARGETS
+# qmltest_DEFAULT_IMPORT_PATHS
+# qmltest_DEFAULT_PROPERTIES
+
+find_program(qmltestrunner_exe qmltestrunner)
+
+if(NOT qmltestrunner_exe)
+  msg(FATAL_ERROR "Could not locate qmltestrunner.")
+endif()
+
+set(qmlscene_exe ${CMAKE_BINARY_DIR}/tests/uqmlscene/uqmlscene)
+
+macro(add_manual_qml_test SUBPATH COMPONENT_NAME)
+    set(options NO_ADD_TEST NO_TARGETS)
+    set(multi_value_keywords IMPORT_PATHS TARGETS PROPERTIES ENVIRONMENT)
+
+    cmake_parse_arguments(qmltest "${options}" "" "${multi_value_keywords}" ${ARGN})
+
+    set(qmlscene_TARGET try${COMPONENT_NAME})
+    set(qmltest_FILE ${SUBPATH}/tst_${COMPONENT_NAME})
+
+    set(qmlscene_imports "")
+    if(NOT "${qmltest_IMPORT_PATHS}" STREQUAL "")
+        foreach(IMPORT_PATH ${qmltest_IMPORT_PATHS})
+            list(APPEND qmlscene_imports "-I")
+            list(APPEND qmlscene_imports ${IMPORT_PATH})
+        endforeach(IMPORT_PATH)
+    elseif(NOT "${qmltest_DEFAULT_IMPORT_PATHS}" STREQUAL "")
+        foreach(IMPORT_PATH ${qmltest_DEFAULT_IMPORT_PATHS})
+            list(APPEND qmlscene_imports "-I")
+            list(APPEND qmlscene_imports ${IMPORT_PATH})
+        endforeach(IMPORT_PATH)
+    endif()
+
+    set(qmlscene_command
+        env ${qmltest_ENVIRONMENT}
+        ${qmlscene_exe} ${CMAKE_CURRENT_SOURCE_DIR}/${qmltest_FILE}.qml
+            ${qmlscene_imports}
+    )
+    add_custom_target(${qmlscene_TARGET} ${qmlscene_command})
+
+endmacro(add_manual_qml_test)
+
+macro(add_qml_benchmark SUBPATH COMPONENT_NAME ITERATIONS)
+    add_qml_test_internal(${SUBPATH} ${COMPONENT_NAME} ${ITERATIONS} ${ARGN})
+endmacro(add_qml_benchmark)
+
+macro(add_qml_test SUBPATH COMPONENT_NAME)
+    add_qml_test_internal(${SUBPATH} ${COMPONENT_NAME} 0 ${ARGN})
+endmacro(add_qml_test)
+
+macro(add_qml_test_internal SUBPATH COMPONENT_NAME ITERATIONS)
+    set(options NO_ADD_TEST NO_TARGETS)
+    set(multi_value_keywords IMPORT_PATHS TARGETS PROPERTIES ENVIRONMENT)
+
+    cmake_parse_arguments(qmltest "${options}" "" "${multi_value_keywords}" ${ARGN})
+
+    set(qmltest_TARGET test${COMPONENT_NAME})
+    set(qmltest_xvfb_TARGET xvfbtest${COMPONENT_NAME})
+    set(qmltest_FILE ${SUBPATH}/tst_${COMPONENT_NAME})
+
+    set(qmltestrunner_imports "")
+    if(NOT "${qmltest_IMPORT_PATHS}" STREQUAL "")
+        foreach(IMPORT_PATH ${qmltest_IMPORT_PATHS})
+            list(APPEND qmltestrunner_imports "-import")
+            list(APPEND qmltestrunner_imports ${IMPORT_PATH})
+        endforeach(IMPORT_PATH)
+    elseif(NOT "${qmltest_DEFAULT_IMPORT_PATHS}" STREQUAL "")
+        foreach(IMPORT_PATH ${qmltest_DEFAULT_IMPORT_PATHS})
+            list(APPEND qmltestrunner_imports "-import")
+            list(APPEND qmltestrunner_imports ${IMPORT_PATH})
+        endforeach(IMPORT_PATH)
+    endif()
+
+    string(TOLOWER "${CMAKE_GENERATOR}" cmake_generator_lower)
+    if(cmake_generator_lower STREQUAL "unix makefiles")
+        set(function_ARGS $(FUNCTION))
+    else()
+        set(function_ARGS "")
+    endif()
+
+    if (${ITERATIONS} GREATER 0)
+        set(ITERATIONS_STRING "-iterations" ${ITERATIONS})
+    else()
+        set(ITERATIONS_STRING "")
+    endif()
+
+    set(qmltest_command
+        env ${qmltest_ENVIRONMENT}
+        ${qmltestrunner_exe} -input ${CMAKE_CURRENT_SOURCE_DIR}/${qmltest_FILE}.qml
+            ${qmltestrunner_imports}
+            ${ITERATIONS_STRING}
+            -o ${CMAKE_BINARY_DIR}/${qmltest_TARGET}.xml,xunitxml
+            -o -,txt
+            ${function_ARGS}
+    )
+    find_program( HAVE_GCC gcc )
+    if (NOT ${HAVE_GCC} STREQUAL "")
+        exec_program( gcc ARGS "-dumpmachine" OUTPUT_VARIABLE ARCH_TRIPLET )
+        set(LD_PRELOAD_PATH "LD_PRELOAD=/usr/lib/${ARCH_TRIPLET}/mesa/libGL.so.1")
+    endif()
+    set(qmltest_xvfb_command
+        env ${qmltest_ENVIRONMENT} ${LD_PRELOAD_PATH}
+        xvfb-run --server-args "-screen 0 1024x768x24" --auto-servernum
+        ${qmltestrunner_exe} -input ${CMAKE_CURRENT_SOURCE_DIR}/${qmltest_FILE}.qml
+        ${qmltestrunner_imports}
+            -o ${CMAKE_BINARY_DIR}/${qmltest_TARGET}.xml,xunitxml
+            -o -,txt
+            ${function_ARGS}
+    )
+
+    add_qmltest_target(${qmltest_TARGET} "${qmltest_command}" TRUE ${qmltest_NO_ADD_TEST})
+    add_qmltest_target(${qmltest_xvfb_TARGET} "${qmltest_xvfb_command}" ${qmltest_NO_TARGETS} TRUE)
+    add_manual_qml_test(${SUBPATH} ${COMPONENT_NAME} ${ARGN})
+endmacro(add_qml_test_internal)
+
+macro(add_binary_qml_test CLASS_NAME LD_PATH DEPS)
+    set(testCommand
+          LD_LIBRARY_PATH=${LD_PATH}
+          ${CMAKE_CURRENT_BINARY_DIR}/${CLASS_NAME}TestExec
+          -o ${CMAKE_BINARY_DIR}/${CLASSNAME}Test.xml,xunitxml
+          -o -,txt)
+
+    add_qmltest_target(test${CLASS_NAME} "${testCommand}" FALSE TRUE)
+    add_dependencies(test${CLASS_NAME} ${CLASS_NAME}TestExec ${DEPS})
+
+    find_program( HAVE_GCC gcc )
+    if (NOT ${HAVE_GCC} STREQUAL "")
+        exec_program( gcc ARGS "-dumpmachine" OUTPUT_VARIABLE ARCH_TRIPLET )
+        set(LD_PRELOAD_PATH "LD_PRELOAD=/usr/lib/${ARCH_TRIPLET}/mesa/libGL.so.1")
+    endif()
+    set(xvfbtestCommand
+          ${LD_PRELOAD_PATH}
+          LD_LIBRARY_PATH=${LD_PATH}
+          xvfb-run --server-args "-screen 0 1024x768x24" --auto-servernum
+          ${CMAKE_CURRENT_BINARY_DIR}/${CLASS_NAME}TestExec
+          -o ${CMAKE_BINARY_DIR}/${CLASS_NAME}Test.xml,xunitxml
+          -o -,txt)
+
+    add_qmltest_target(xvfbtest${CLASS_NAME} "${xvfbtestCommand}" FALSE TRUE)
+    add_dependencies(qmluitests xvfbtest${CLASS_NAME})
+endmacro(add_binary_qml_test)
+
+macro(add_qmltest_target qmltest_TARGET qmltest_command qmltest_NO_TARGETS qmltest_NO_ADD_TEST)
+    add_custom_target(${qmltest_TARGET} ${qmltest_command})
+
+    if(NOT "${qmltest_PROPERTIES}" STREQUAL "")
+        set_target_properties(${qmltest_TARGET} PROPERTIES ${qmltest_PROPERTIES})
+    elseif(NOT "${qmltest_DEFAULT_PROPERTIES}" STREQUAL "")
+        set_target_properties(${qmltest_TARGET} PROPERTIES ${qmltest_DEFAULT_PROPERTIES})
+    endif()
+
+    if("${qmltest_NO_ADD_TEST}" STREQUAL FALSE AND NOT "${qmltest_DEFAULT_NO_ADD_TEST}" STREQUAL "TRUE")
+        add_test(${qmltest_TARGET} ${qmltest_command})
+
+        if(NOT "${qmltest_UNPARSED_ARGUMENTS}" STREQUAL "")
+            set_tests_properties(${qmltest_TARGET} PROPERTIES ${qmltest_PROPERTIES})
+        elseif(NOT "${qmltest_DEFAULT_PROPERTIES}" STREQUAL "")
+            set_tests_properties(${qmltest_TARGET} PROPERTIES ${qmltest_DEFAULT_PROPERTIES})
+        endif()
+    endif("${qmltest_NO_ADD_TEST}" STREQUAL FALSE AND NOT "${qmltest_DEFAULT_NO_ADD_TEST}" STREQUAL "TRUE")
+
+    if("${qmltest_NO_TARGETS}" STREQUAL "FALSE")
+        if(NOT "${qmltest_TARGETS}" STREQUAL "")
+            foreach(TARGET ${qmltest_TARGETS})
+                add_dependencies(${TARGET} ${qmltest_TARGET})
+            endforeach(TARGET)
+        elseif(NOT "${qmltest_DEFAULT_TARGETS}" STREQUAL "")
+            foreach(TARGET ${qmltest_DEFAULT_TARGETS})
+                add_dependencies(${TARGET} ${qmltest_TARGET})
+            endforeach(TARGET)
+        endif()
+    endif("${qmltest_NO_TARGETS}" STREQUAL "FALSE")
+
+endmacro(add_qmltest_target)

=== added file 'cmake/modules/autopilot.cmake'
--- cmake/modules/autopilot.cmake	1970-01-01 00:00:00 +0000
+++ cmake/modules/autopilot.cmake	2014-09-17 20:40:39 +0000
@@ -0,0 +1,24 @@
+add_custom_target(autopilot)
+
+function(declare_autopilot_test TEST_NAME TEST_SUITE WORKING_DIR)
+    add_custom_target(autopilot-${TEST_NAME}
+        COMMAND LANG=C UBUNTU_ICON_THEME=ubuntu-mobile QML2_IMPORT_PATH=${SHELL_INSTALL_QML}/mocks python3 -m autopilot.run run ${TEST_SUITE}
+        WORKING_DIRECTORY ${WORKING_DIR}
+        DEPENDS fake_install
+    )
+
+    add_custom_target(fake_install
+        COMMAND cmake --build ${CMAKE_BINARY_DIR} --target install
+    )
+
+    add_dependencies(autopilot autopilot-${TEST_NAME})
+
+    add_custom_target(autopilot2-${TEST_NAME}
+        COMMAND LANG=C UBUNTU_ICON_THEME=ubuntu-mobile QML2_IMPORT_PATH=${SHELL_INSTALL_QML}/mocks python2 -m autopilot.run run ${TEST_SUITE}
+        WORKING_DIRECTORY ${WORKING_DIR}
+        DEPENDS fake_install
+    )
+
+    add_dependencies(autopilot autopilot2-${TEST_NAME})
+
+endfunction()

